% Calculates total loss and peak SAR for Table 13 of IEC/IEEE 62704-4/D2
% based on the Mie analytical solution

% The calculation is based on the derivation published in the book:
% Craig F. Bohren, Donald R. Huffman, Absorption and scattering of light by small particles
% Chapter 4, John Wiley & Sons, 1983

clear all; close all; clc

addpath(genpath(pwd));  % add functions
cd ..
addpath(genpath(pwd));  % add functions
cd field_plot

mie_parameters % load parameters from script

E2 = plot_magE_field(params);

xsize = length(params.x_grid); 
ysize = length(params.y_grid);
zsize = length(params.z_grid);

%% Plot 

plane = 1;

if( plane == 1 )
    
    % XY plane
    E2_xy = squeeze(E2(:,:,round(zsize/2)));
    figure(1)
    pcolor(params.x_grid,params.y_grid,E2_xy.')
    shading interp
    xlabel('x [m]')
    ylabel('y [m]')
    hold on
    title('magE(t=0) on the XY plane')
    colorbar;
    colormap;
    
elseif( plane == 2 )
    
    % XZ plane
    E2_xz = squeeze(E2(:,round(ysize/2),:));
    figure(2)
    pcolor(params.x_grid,params.z_grid,E2_xz.')
    shading interp
    xlabel('x [m]')
    ylabel('z [m]')
    hold on
    title('magE(t=0) on the XZ plane')
    colorbar;
    colormap;
    
else
    
    % YZ plane
    E2_yz = squeeze(E2(round(xsize/2),:,:));
    figure(3)
    pcolor(params.y_grid,params.z_grid,E2_yz.')
    shading interp
    xlabel('y [m]')
    ylabel('z [m]')
    hold on
    title('magE(t=0) on the YZ plane')
    colorbar;
    colormap;
    
end

