function [E2] = plot_magE_field(params)

% Calculation of the volumetric point SAR + calculate error measre compared
% to numerically computed peak SAR values - found in 'evalFile'
% peak SAR values must be in specified order and on a specified grid

% evalFile = 'dataForErrorComputation/MieSphere3DGrid_localSAR.fld';



% compute coefficients
result = Mie_cd(params.x0,params.m, params);
c=result(1,:);
d=result(2,:);

%% init progress bar
wb = waitbar(0,'Calculating E-field');

%%

resolution = params.resolution;
x_vec = params.x_grid;
y_vec = params.y_grid;
z_vec = params.z_grid;

%

num_grid_points = length(x_vec)*length(y_vec)*length(z_vec);
current_grid_point = 1;
IJK = zeros(num_grid_points,3);
XYZ = zeros(num_grid_points,3);

E2 = zeros(length(x_vec),length(y_vec),length(z_vec));

% step x,y,z coordinates
for x_index = 1:length(x_vec)
    x = x_vec(x_index);
    wb = waitbar((x_index)/length(x_vec),wb);
    %disp([num2str(floor(100 * current_grid_point/num_grid_points)) '%' ])

    %     round(100*(x_index)/length(x_vec))
    for y_index = 1:length(y_vec)
        y = y_vec(y_index);
        for z_index = 1:length(z_vec)
            z = z_vec(z_index);
            
            % GRID
            IJK(current_grid_point,1) = x_index-1;
            IJK(current_grid_point,2) = y_index-1;
            IJK(current_grid_point,3) = z_index-1;
            XYZ(current_grid_point,1) = x;
            XYZ(current_grid_point,2) = y;
            XYZ(current_grid_point,3) = z;
            
            % coordinate conversion from cartesian to spherical
            rc = sqrt(x^2+y^2+z^2);
            theta = atan2(sqrt(x^2+y^2), z);
            phi = atan2(y,x);
            
            % omit calculation outside sphere
            if((rc) > params.a ) % TODO: r=0
                E_field_sph = [0 0 0];
                E_field_x = 0;
                E_field_y = 0;
                E_field_z = 0;
                % calculate inside
            else
                %% TODO: normalization with E0 in evaluation file!
                E_field_sph = computeE1atSphCoords(rc, theta, phi, c, d,  params);
                
                % convert to cartesian
                %-Z [E_field_x, E_field_y, E_field_z]= sph2cart(E_field_sph(3),E_field_sph(2),E_field_sph(1));
                cph = cos(phi);
                sph = sin(phi);
                cth = cos(theta);
                sth = sin(theta);
                E_field_x = E_field_sph(1)*sth*cph + E_field_sph(2)*cth*cph - E_field_sph(3)*sph;
                E_field_y = E_field_sph(1)*sth*sph + E_field_sph(2)*cth*sph + E_field_sph(3)*cph;
                E_field_z = E_field_sph(1)*cth     - E_field_sph(2)*sth;
                
            end
            
            E2(x_index,y_index,z_index) = sqrt( real(E_field_x)^2 + real(E_field_y)^2 + real(E_field_z)^2 );

                        
        end
    end
end
close(wb)


