function [ E_field ] = computeE1atSphCoords(r, theta, phi, c, d,  params)
% returns the E field inside the sphere;
% input location is in spherical coordinates

%%
% get number of coefficients
nj = length(c);

% convert radius to relative wavelength
km = params.k0 * params.m;
rho = r*km; % rho = r*k

% vector for pi and tau
p = zeros(nj,1);
t = zeros(nj,1);

% (4.47)
% first 3 values of pi and tau
p(1) = 0;
p(2) = 1;

t(1) = 0;
t(2) = cos(theta);

% calculate pi and tau based on recursive formula
for ni = 3:nj+1
    n = ni-1;
    p(ni) = (2*n-1)/(n-1) * cos(theta) * p(ni-1) - n/(n-1) * p(ni-2);
    t(ni) = n*cos(theta) * p(ni) - (n+1) * p(ni-1);
end

%% calculate internal E field from Mie series formula
% Book 4.50: M_o1n and N_e1n

% init value is 0
E_field = [0;0;0];
for n = 1:nj
    % spherical Bessel
    j_rmx = sphbes(n,rho, params);
    % M_o1n
    M1 = 0;
    M2 = cos(phi) * p(n+1)  * j_rmx;
    M3 = -sin(phi) * t(n+1) * j_rmx;
    
    M_act = [M1;M2;M3];
    % N_e1n
    j_rmx_per_rho = sphbes_per_x(n,rho, params);
    j_rmx_v_per_rho = d_x_sphbes_per_x(n,rho, params);
    
    N1 = n*(n+1) * cos(phi) * sin(theta) * p(n+1) * j_rmx_per_rho;
    N2 = cos(phi) * t(n+1) * j_rmx_v_per_rho;
    N3 = -sin(phi) * p(n+1) * j_rmx_v_per_rho;
    
    N_act = [N1;N2;N3];
    
    % sum up i^th term
    E_field = E_field + (1i)^n*(2*n+1)/(n*(n+1)) * (M_act * c(n) - N_act * 1i *d(n));
end

E_field = params.E0 * E_field;

end




