% Vacuum and Layered Weak Patch Test 
% 
% 1. the grid points for error computation is generated
% 2. the error measures (rms, max and origin) in E and H are computed

%% Initialization
clear all; close all; clc
addpath(genpath(pwd));

WeakPatchTest_parameters  % load parameters from script


%% Generates and saves grid indexes (i,j,k) and point coordinates (x,y,z); 
%   the indexes (i,j,k) start at 0 and 

[IJK, XYZ] = generateGrid(params);
nofGPoints = saveGrid('TestDATA//GridPoints.txt', IJK, XYZ)

%% Calculates errors in <<< Vacuum >>> Patch Test for E compared to analytical solution

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PREREQUISITE: Read in the complex E vectors on the grid to the workspace in the 
%               format defined in Annex C.
%               Field file examples can be found in TestDATA subdirectory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ABC_VE = Vacuum_Efield_FineH0curl; % imported from example file Vacuum_Hfield_FineH0curl.txt
[ rmsErr, maxErr, oriErr ] = computeEfieldErrorInVacuumCube(params, ABC_VE);
disp(['____________________________________']);
disp(['                            ']);
disp(['Vacume Patch Test Electric Field']);
disp(['--------------------------------']);
disp(['           x      y       z']);
disp(['rms(%) = ' num2str(100*rmsErr(1)) '  ' num2str(100*rmsErr(2)) '  ' num2str(100*rmsErr(3)) ]);
disp(['max(%) = ' num2str(100*maxErr(1)) '  ' num2str(100*maxErr(2)) '  ' num2str(100*maxErr(3)) ]);
disp(['ori(%) = ' num2str(100*oriErr(1)) '  ' num2str(100*oriErr(2)) '  ' num2str(100*oriErr(3)) ]);
disp(['____________________________________']);


%% Calculates errors in <<< Vacuum >>> Patch Test for H compared to analytical solution

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PREREQUISITE: Read in the complex E vectors on the grid to the workspace in the 
%               format defined in Annex C.
%               Field file examples can be found in TestDATA subdirectory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ABC_VH = Vacuum_Hfield_FineH0curl; % imported from example file Vacuum_Hfield_FineH0curl.txt
[ rmsErr, maxErr, oriErr ] = computeHfieldErrorInVacuumCube(params, ABC_VH);
disp(['____________________________________']);
disp(['                            ']);
disp(['Vacume Patch Test Magnetic Field']);
disp(['--------------------------------']);
disp(['           x      y       z']);
disp(['rms(%) = ' num2str(100*rmsErr(1)) '  ' num2str(100*rmsErr(2)) '  ' num2str(100*rmsErr(3)) ]);
disp(['max(%) = ' num2str(100*maxErr(1)) '  ' num2str(100*maxErr(2)) '  ' num2str(100*maxErr(3)) ]);
disp(['ori(%) = ' num2str(100*oriErr(1)) '  ' num2str(100*oriErr(2)) '  ' num2str(100*oriErr(3)) ]);
disp(['____________________________________']);


%% Calculates errors in <<< Layered >>> Patch Test for E compared to analytical solution

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PREREQUISITE: Read in the complex E vectors on the grid to the workspace in the 
%               format defined in Annex C.
%               Field file examples can be found in TestDATA subdirectory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ABC_LE = Layered_Efield_FineH2curl; % imported from example file Layered_Efield_FineH0curl.txt
[ rmsErr, maxErr, oriErr ] = computeEfieldErrorInLayeredCube(params, ABC_LE);
disp(['____________________________________']);
disp(['                            ']);
disp(['Layered Patch Test Electric Field']);
disp(['---------------------------------']);
disp(['           x      y       z']);
disp(['rms(%) = ' num2str(100*rmsErr(1)) '  ' num2str(100*rmsErr(2)) '  ' num2str(100*rmsErr(3)) ]);
disp(['max(%) = ' num2str(100*maxErr(1)) '  ' num2str(100*maxErr(2)) '  ' num2str(100*maxErr(3)) ]);
disp(['ori(%) = ' num2str(100*oriErr(1)) '  ' num2str(100*oriErr(2)) '  ' num2str(100*oriErr(3)) ]);
disp(['____________________________________']);


%% Calculates errors in <<< Layered >>> Patch Test for H compared to analytical solution

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PREREQUISITE: Read in the complex E vectors on the grid to the workspace in the 
%               format defined in Annex C.
%               Field file examples can be found in TestDATA subdirectory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ABC_LH = Layered_Hfield_FineH2curl; % imported from example file Layered_Hfield_FineH2curl.txt
[ rmsErr, maxErr, oriErr ] = computeHfieldErrorInLayeredCube(params, ABC_LH);
disp(['____________________________________']);
disp(['                            ']);
disp(['Layered Patch Test Magnetic Field']);
disp(['---------------------------------']);
disp(['           x      y       z']);
disp(['rms(%) = ' num2str(100*rmsErr(1)) '  ' num2str(100*rmsErr(2)) '  ' num2str(100*rmsErr(3)) ]);
disp(['max(%) = ' num2str(100*maxErr(1)) '  ' num2str(100*maxErr(2)) '  ' num2str(100*maxErr(3)) ]);
disp(['ori(%) = ' num2str(100*oriErr(1)) '  ' num2str(100*oriErr(2)) '  ' num2str(100*oriErr(3)) ]);
disp(['____________________________________']);


