clear all; close all; clc

% some constants
params.c_light = 299792458;         % [m/s]
params.mu0 = 4*pi*1E-7;             % [H/m]
params.eps0 = 1/params.mu0/params.c_light/params.c_light;    % [F/m]
params.eta0 = sqrt(params.mu0/params.eps0);     % vacuum intrinsic impedance [Ohm]

% input data defined in Section 8.3.2 in IEC/IEEE 62704-4

% vacuum
params.freq = 3e9;              % frequency of excitation [Hz]
params.w = params.freq*2*pi;                    % angular frequency
params.E0 = 1;                  % amplitude of incident wave [V/m]

params.lambda0 = params.c_light/params.freq;    % wavelength in vacuum
params.k0 = 2*pi / params.lambda0;              % wavenumber in surrounding medium

params.L = params.lambda0 / 2;

% layered
params.eps_r1 = 4;
params.h = params.L/4;

params.k1 = params.k0 * sqrt(params.eps_r1);        % wavenumber of the dielectric layer
params.eta1 = params.eta0 / sqrt(params.eps_r1);

% cartesian grid - x/y/z
params.M1 = 10;
params.delta = params.L/params.M1;
params.M = (params.M1-1)^3

